@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: cli.py 624 2005-02-27 03:30:30Z pronovic $
+# Revision : $Id: cli.py 659 2005-03-06 20:23:01Z pronovic $
 # Purpose  : Provides command-line interface implementation.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -1361,3 +1361,12 @@ class Options(object):
       if switches.has_key("-s") or switches.has_key("--stack"):
          self.stacktrace = True
 
+
+#########################################################################
+# Main routine
+########################################################################
+
+if __name__ == "__main__":
+   result = cli()
+   sys.exit(result)
+
