@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 625 2005-02-27 03:32:28Z pronovic $
+# Revision : $Id: release.py 687 2005-03-08 19:36:54Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2005"
-VERSION     = "2.0.0"
-DATE        = "26 Feb 2005"
+VERSION     = "2.1.3"
+DATE        = "08 Mar 2005"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
