@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 606 2005-02-25 15:40:51Z pronovic $
+# Revision : $Id: util.py 686 2005-03-08 19:32:58Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -40,17 +40,20 @@
 """
 Provides general-purpose utilities. 
 
-@sort: AbsolutePathList, ObjectTypeList, convertSize, getUidGid, 
+@sort: AbsolutePathList, ObjectTypeList, convertSize, getUidGid, changeOwnership, 
        splitCommandLine, executeCommand, calculateFileAge, encodePath, 
-       ISO_SECTOR_SIZE, BYTES_PER_KBYTE, KBYTES_PER_MBYTE, BYTES_PER_MBYTE,
-       BYTES_PER_SECTOR, SECONDS_PER_MINUTE, MINUTES_PER_HOUR, HOURS_PER_DAY, 
-       SECONDS_PER_DAY, UNIT_BYTES, UNIT_KBYTES, UNIT_MBYTES, UNIT_SECTORS
+       ISO_SECTOR_SIZE, BYTES_PER_SECTOR, 
+       BYTES_PER_KBYTE, BYTES_PER_MBYTE, BYTES_PER_GBYTE, KBYTES_PER_MBYTE, MBYTES_PER_GBYTE, 
+       SECONDS_PER_MINUTE, MINUTES_PER_HOUR, HOURS_PER_DAY, SECONDS_PER_DAY, 
+       UNIT_BYTES, UNIT_KBYTES, UNIT_MBYTES, UNIT_SECTORS
 
 @var ISO_SECTOR_SIZE: Size of an ISO image sector, in bytes.
-@var BYTES_PER_KBYTE: Number of bytes (B) per kilobyte (kB).
-@var KBYTES_PER_MBYTE: Number of kilobytes (kB) per megabyte (MB).
-@var BYTES_PER_MBYTE: Number of bytes (B) per megabyte (MB).
 @var BYTES_PER_SECTOR: Number of bytes (B) per ISO sector.
+@var BYTES_PER_KBYTE: Number of bytes (B) per kilobyte (kB).
+@var BYTES_PER_MBYTE: Number of bytes (B) per megabyte (MB).
+@var BYTES_PER_GBYTE: Number of bytes (B) per megabyte (GB).
+@var KBYTES_PER_MBYTE: Number of kilobytes (kB) per megabyte (MB).
+@var MBYTES_PER_GBYTE: Number of megabytes (MB) per gigabyte (GB).
 @var SECONDS_PER_MINUTE: Number of seconds per minute.
 @var MINUTES_PER_HOUR: Number of minutes per hour.
 @var HOURS_PER_DAY: Number of hours per day.
@@ -69,6 +72,7 @@ Provides general-purpose utilities.
 ########################################################################
 
 import sys
+import math
 import os
 import re
 import time
@@ -87,11 +91,13 @@ logger = logging.getLogger("CedarBackup2.log.util")
 outputLogger = logging.getLogger("CedarBackup2.output")
 
 ISO_SECTOR_SIZE    = 2048.0   # in bytes
+BYTES_PER_SECTOR   = ISO_SECTOR_SIZE
 
 BYTES_PER_KBYTE    = 1024.0
 KBYTES_PER_MBYTE   = 1024.0
+MBYTES_PER_GBYTE   = 1024.0
 BYTES_PER_MBYTE    = BYTES_PER_KBYTE * KBYTES_PER_MBYTE
-BYTES_PER_SECTOR   = ISO_SECTOR_SIZE
+BYTES_PER_GBYTE    = BYTES_PER_MBYTE * MBYTES_PER_GBYTE
 
 SECONDS_PER_MINUTE = 60
 MINUTES_PER_HOUR   = 60
@@ -439,7 +445,53 @@ def convertSize(size, fromUnit, toUnit):
       return byteSize / BYTES_PER_SECTOR
    else:
       raise ValueError("Unknown 'to' unit %d." % toUnit)
-   
+
+##########################
+# displayBytes() function
+##########################
+
+def displayBytes(bytes, digits=2):
+   """
+   Format a byte quantity so it can be sensibly displayed.
+
+   It's rather difficult to look at a number like "72372224 bytes" and get any
+   meaningful information out of it.  It would be more useful to see something
+   like "72.37 MB".  That's what this function does.  Any time you want to display
+   a byte value, i.e.::
+
+      print "Size: %s bytes" % bytes
+
+   Call this function instead::
+
+      print "Size: %s" % displayBytes(bytes)
+
+   What comes out will be sensibly formatted.  The indicated number of digits
+   will be listed after the decimal point, rounded based on whatever rules are
+   used by Python's standard C{%f} string format specifier.
+
+   @param bytes: Byte quantity.
+   @type bytes: Integer number of bytes.
+
+   @param digits: Number of digits to display after the decimal point.
+   @type digits: Integer value, typically 2-5.
+
+   @return: String, formatted for sensible display.
+   """
+   bytes = float(bytes)
+   if math.fabs(bytes) < BYTES_PER_KBYTE:
+      format = "%.0f bytes"
+      value = bytes
+   elif math.fabs(bytes) < BYTES_PER_MBYTE:
+      format = "%." + "%d" % digits + "f kB"
+      value = bytes / BYTES_PER_KBYTE
+   elif math.fabs(bytes) < BYTES_PER_GBYTE:
+      format = "%." + "%d" % digits + "f MB"
+      value = bytes / BYTES_PER_MBYTE
+   else:
+      format = "%." + "%d" % digits + "f GB"
+      value = bytes / BYTES_PER_GBYTE
+   return format % value
+
 
 ##################################
 # getFunctionReference() function
@@ -524,6 +576,24 @@ def getUidGid(user, group):
       raise ValueError("Unable to lookup up uid and gid for passed in user/group.")
 
 
+#############################
+# changeOwnership() function
+#############################
+
+def changeOwnership(path, user, group):
+   """
+   Changes ownership of path to match the user and group.
+   @param path: Path whose ownership to change.
+   @param user: User which owns file.
+   @param group: Group which owns file.
+   """
+   try:
+      (uid, gid) = getUidGid(user, group)
+      os.chown(path, uid, gid)
+   except Exception, e:
+      logger.error("Error changing ownership of [%s]: %s" % (path, e))
+
+
 ##############################
 # splitCommandLine() function
 ##############################
@@ -556,7 +626,7 @@ def splitCommandLine(commandLine):
 # executeCommand() function
 ############################
 
-def executeCommand(command, args, returnOutput=False, ignoreStderr=False):
+def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotLog=False, outputFile=None):
    """
    Executes a shell command, hopefully in a safe way (UNIX-specific).
 
@@ -585,6 +655,19 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False):
    included in the output.  This is implemented by using L{popen2.Popen4} in
    the normal case and L{popen2.Popen3} if C{stderr} is to be ignored.
 
+   The C{doNotLog} parameter exists so that callers can force the function
+   to not log command output to the debug log.  Normally, you would want to
+   log.  However, if you're using this function to write huge output files
+   (i.e. database backups written to stdout) then you might want to avoid
+   putting all that information into the debug log.
+
+   The C{outputFile} parameter exists to make it easier for a caller to push
+   output into a file, i.e. as a substitute for redirection to a file.  If this
+   value is passed in, each time a line of output is generated, it will be
+   written to the file using C{outputFile.write()}.  At the end, the file
+   descriptor will be flushed using C{outputFile.flush()}.  The caller
+   maintains responsibility for closing the file object appropriately.
+
    @note: I know that it's a bit confusing that the command and the arguments
    are both lists.  I could have just required the caller to pass in one big
    list.  However, I think it makes some sense to keep the command (the
@@ -605,9 +688,19 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False):
    @param returnOutput: Indicates whether to return the output of the command
    @type returnOutput: Boolean C{True} or C{False}
 
+   @param doNotLog: Indicates that output should not be logged.
+   @type doNotLog: Boolean C{True} or C{False}
+
+   @param outputFile: File object that all output should be written to.
+   Type outputFile: File object as returned from C{open()} or C{file()}.
+
    @return: Tuple of C{(result, output)} as described above.
    """
    logger.debug("Executing command %s with args %s." % (command, args))
+   outputLogger.info("Executing command %s with args %s." % (command, args))
+   if doNotLog:
+      logger.debug("Note: output will not be logged, per the doNotLog flag.")
+      outputLogger.info("Note: output will not be logged, per the doNotLog flag.")
    output = []
    fields = command[:]        # make sure to copy it so we don't destroy it
    fields.extend(args)
@@ -620,7 +713,12 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False):
       line = pipe.fromchild.readline()
       if not line: break
       if returnOutput: output.append(line)
-      outputLogger.info(line[:-1])  # this way the log will (hopefully) get updated in realtime
+      if outputFile is not None: outputFile.write(line)
+      if not doNotLog: outputLogger.info(line[:-1])  # this way the log will (hopefully) get updated in realtime
+   if outputFile is not None: 
+      try: # note, not every file-like object can be flushed
+         outputFile.flush()
+      except: pass
    if returnOutput:
       return (pipe.wait(), output)
    else:
